
TODO: TODO_72_51_13_18: test optimized requests

TODO: Provide test coverage for special implementation: `ClientCommandRemoteWorkerTextProposeArgValuesOptimized`

It became more important with implementation of FS_93_18_57_91 client fail over to redundant servers.

